From 923c20d153400b5278e29464d68046535f319f6b Mon Sep 17 00:00:00 2001
From: Andreas Gerler <baron@bundesbrandschatzamt.de>
Date: Sat, 7 Jan 2023 14:04:03 +0100
Subject: [PATCH] * lisp/ob-eval.el: Display error fix

* lisp/ob-eval.el: (org-babel-eval-error-notify): Display standard
error only if command exits non zero.

The problem is that sql connections might give warnings.
Now the information is available in the *Org-Babel Error* buffer
without displaying.
If you need always display toggle org-babel-eval-error-display-notify.

Signed-off-by: Andreas Gerler <baron@bundesbrandschatzamt.de>
---
 lisp/ob-eval.el | 12 +++++++++++-
 1 file changed, 11 insertions(+), 1 deletion(-)

diff --git a/lisp/ob-eval.el b/lisp/ob-eval.el
index 6f6edb949..18ca48218 100644
--- a/lisp/ob-eval.el
+++ b/lisp/ob-eval.el
@@ -36,6 +36,12 @@
 (defvar org-babel-error-buffer-name "*Org-Babel Error Output*")
 (declare-function org-babel-temp-file "ob-core" (prefix &optional suffix))
 
+(defcustom org-babel-eval-error-display-notify nil
+  "Display org-babel-eval-errors always or only if exit code is not 0."
+  :group 'org-babel
+  :version "29.1"
+  :type 'boolean)
+
 (defun org-babel-eval-error-notify (exit-code stderr)
   "Open a buffer to display STDERR and a message with the value of EXIT-CODE."
   (let ((buf (get-buffer-create org-babel-error-buffer-name)))
@@ -45,7 +51,11 @@
         (unless (bolp) (insert "\n"))
         (insert stderr)
         (insert (format "[ Babel evaluation exited with code %S ]" exit-code))))
-    (display-buffer buf))
+    (if org-babel-eval-error-display-notify
+        (display-buffer buf)
+      (if (or (not (numberp exit-code))
+              (> exit-code 0))
+          (display-buffer buf))))
   (message "Babel evaluation exited with code %S" exit-code))
 
 (defun org-babel-eval (command query)
-- 
2.39.0

